data {
  int<lower=0> N;
  int<lower=0> n_age;
  int<lower=0> n_age_edu;
  int<lower=0> n_edu;
  int<lower=0> n_region_full;
  int<lower=0> n_state;
  int<lower=0,upper=n_age> age[N];
  int<lower=0,upper=n_age_edu> age_edu[N];
  vector<lower=0,upper=1>[N] black;
  int<lower=0,upper=n_edu> edu[N];
  vector<lower=0,upper=1>[N] female;
  int<lower=0,upper=n_region_full> region_full[N];
  int<lower=0,upper=n_state> state[N];
  vector[N] v_prev_full;
  int<lower=0,upper=1> y[N];
}

parameters {
  vector[2] beta;
  vector[n_state] s;
  real<lower=0> sigma_s;
  real mu_s;
  vector[n_edu] e;
  real<lower=0> sigma_e;
  real mu_e;
}

model {
  vector[N] y_hat;

  mu_s    ~ normal(0, 10);
  sigma_s ~ lognormal(0, 10);
  s       ~ normal (mu_s, sigma_s);

  mu_e    ~ normal(0, 10);
  sigma_e ~ lognormal(0, 10);
  e       ~ normal (mu_e, sigma_e);

  beta ~ normal (0, 1);

  for (n in 1:N) {
    y_hat[n] =  beta[1] * black[n] 
                + beta[2] * female[n] 
                + s[state[n]]
                + e[edu[n]];
  }
  y ~ bernoulli_logit(y_hat);
}

generated quantities {
  vector[N] lp_users;
  for (n in 1:N) {
    lp_users[n] = bernoulli_logit_log(
      y[n], 
      beta[1] * black[n] 
      + beta[2] * female[n] 
      + s[state[n]]
      + e[edu[n]]);
  }
}
