data {
  int N;          // number of data points
  int K;          // number of mixture components  
  int X[N];       // dataset
  real<lower=0> mu_a;
  real<lower=0> mu_b;  
  real<lower=0> pi_alpha;
}

transformed data {
  vector[K] pi_alpha_vec;
  for (k in 1:K)
    pi_alpha_vec[k] = pi_alpha;
}

parameters {
  simplex[K] pi;
  real<lower=0> mu[K];
  real<lower=0> phi[K];
}

model {
  pi ~ dirichlet(pi_alpha_vec);
  to_vector(mu) ~  gamma(mu_a, mu_b);
  to_vector(phi) ~ gamma(1, 0.01);
  for (n in 1:N) {
    real ps[K];
    for (k in 1:K) {
      ps[k] = log(pi[k]) + neg_binomial_2_log(X[n], mu[k], phi[k]);
    }
    target += log_sum_exp(ps);
  }  
}

generated quantities {
  vector[N] log_post_pred;
  # vector[5000] plot_log_post_pred;
  for (n in 1:N) {
   real ps[K];
    for (k in 1:K) {
      ps[k] = log(pi[k]) + neg_binomial_2_log(X[n], mu[k], phi[k]);
    }
    log_post_pred[n] = log_sum_exp(ps);
  }
  # for (n in 1:5000) {
  #   real ps[K];
  #   for (k in 1:K) {
  #     ps[k] = log(pi[k]) + neg_binomial_2_log(n, mu[k], phi[k]);
  #   }
  #   plot_log_post_pred[n] = log_sum_exp(ps);
  # }  
}
